
# Class: named thing




URI: [https://example.com/test62/NamedThing](https://example.com/test62/NamedThing)


[![img](https://yuml.me/diagram/nofunky;dir:TB/class/[NamedThing&#124;category:iri_type%20%2B])](https://yuml.me/diagram/nofunky;dir:TB/class/[NamedThing&#124;category:iri_type%20%2B])

## Referenced by Class


## Attributes


### Own

 * [category](category.md)  <sub>1..\*</sub>
     * Range: [IriType](types/IriType.md)
